"""
Main interface for databrew service type definitions.

Usage::

    ```python
    from mypy_boto3_databrew.type_defs import ConditionExpressionTypeDef

    data: ConditionExpressionTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Any, Dict, List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "ConditionExpressionTypeDef",
    "CsvOptionsTypeDef",
    "CsvOutputOptionsTypeDef",
    "DataCatalogInputDefinitionTypeDef",
    "DatasetTypeDef",
    "ExcelOptionsTypeDef",
    "FormatOptionsTypeDef",
    "InputTypeDef",
    "JobRunTypeDef",
    "JobSampleTypeDef",
    "JobTypeDef",
    "JsonOptionsTypeDef",
    "OutputFormatOptionsTypeDef",
    "OutputTypeDef",
    "ProjectTypeDef",
    "RecipeActionTypeDef",
    "RecipeReferenceTypeDef",
    "RecipeStepTypeDef",
    "RecipeTypeDef",
    "RecipeVersionErrorDetailTypeDef",
    "ResponseMetadata",
    "S3LocationTypeDef",
    "SampleTypeDef",
    "ScheduleTypeDef",
    "BatchDeleteRecipeVersionResponseTypeDef",
    "CreateDatasetResponseTypeDef",
    "CreateProfileJobResponseTypeDef",
    "CreateProjectResponseTypeDef",
    "CreateRecipeJobResponseTypeDef",
    "CreateRecipeResponseTypeDef",
    "CreateScheduleResponseTypeDef",
    "DeleteDatasetResponseTypeDef",
    "DeleteJobResponseTypeDef",
    "DeleteProjectResponseTypeDef",
    "DeleteRecipeVersionResponseTypeDef",
    "DeleteScheduleResponseTypeDef",
    "DescribeDatasetResponseTypeDef",
    "DescribeJobResponseTypeDef",
    "DescribeJobRunResponseTypeDef",
    "DescribeProjectResponseTypeDef",
    "DescribeRecipeResponseTypeDef",
    "DescribeScheduleResponseTypeDef",
    "ListDatasetsResponseTypeDef",
    "ListJobRunsResponseTypeDef",
    "ListJobsResponseTypeDef",
    "ListProjectsResponseTypeDef",
    "ListRecipeVersionsResponseTypeDef",
    "ListRecipesResponseTypeDef",
    "ListSchedulesResponseTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "PaginatorConfigTypeDef",
    "PublishRecipeResponseTypeDef",
    "SendProjectSessionActionResponseTypeDef",
    "StartJobRunResponseTypeDef",
    "StartProjectSessionResponseTypeDef",
    "StopJobRunResponseTypeDef",
    "UpdateDatasetResponseTypeDef",
    "UpdateProfileJobResponseTypeDef",
    "UpdateProjectResponseTypeDef",
    "UpdateRecipeJobResponseTypeDef",
    "UpdateRecipeResponseTypeDef",
    "UpdateScheduleResponseTypeDef",
    "ViewFrameTypeDef",
)

_RequiredConditionExpressionTypeDef = TypedDict(
    "_RequiredConditionExpressionTypeDef", {"Condition": str, "TargetColumn": str}
)
_OptionalConditionExpressionTypeDef = TypedDict(
    "_OptionalConditionExpressionTypeDef", {"Value": str}, total=False
)


class ConditionExpressionTypeDef(
    _RequiredConditionExpressionTypeDef, _OptionalConditionExpressionTypeDef
):
    pass


CsvOptionsTypeDef = TypedDict(
    "CsvOptionsTypeDef", {"Delimiter": str, "HeaderRow": bool}, total=False
)

CsvOutputOptionsTypeDef = TypedDict("CsvOutputOptionsTypeDef", {"Delimiter": str}, total=False)

_RequiredDataCatalogInputDefinitionTypeDef = TypedDict(
    "_RequiredDataCatalogInputDefinitionTypeDef", {"DatabaseName": str, "TableName": str}
)
_OptionalDataCatalogInputDefinitionTypeDef = TypedDict(
    "_OptionalDataCatalogInputDefinitionTypeDef",
    {"CatalogId": str, "TempDirectory": "S3LocationTypeDef"},
    total=False,
)


class DataCatalogInputDefinitionTypeDef(
    _RequiredDataCatalogInputDefinitionTypeDef, _OptionalDataCatalogInputDefinitionTypeDef
):
    pass


_RequiredDatasetTypeDef = TypedDict(
    "_RequiredDatasetTypeDef", {"Name": str, "Input": "InputTypeDef"}
)
_OptionalDatasetTypeDef = TypedDict(
    "_OptionalDatasetTypeDef",
    {
        "AccountId": str,
        "CreatedBy": str,
        "CreateDate": datetime,
        "Format": Literal["CSV", "JSON", "PARQUET", "EXCEL"],
        "FormatOptions": "FormatOptionsTypeDef",
        "LastModifiedDate": datetime,
        "LastModifiedBy": str,
        "Source": Literal["S3", "DATA-CATALOG"],
        "Tags": Dict[str, str],
        "ResourceArn": str,
    },
    total=False,
)


class DatasetTypeDef(_RequiredDatasetTypeDef, _OptionalDatasetTypeDef):
    pass


ExcelOptionsTypeDef = TypedDict(
    "ExcelOptionsTypeDef",
    {"SheetNames": List[str], "SheetIndexes": List[int], "HeaderRow": bool},
    total=False,
)

FormatOptionsTypeDef = TypedDict(
    "FormatOptionsTypeDef",
    {"Json": "JsonOptionsTypeDef", "Excel": "ExcelOptionsTypeDef", "Csv": "CsvOptionsTypeDef"},
    total=False,
)

InputTypeDef = TypedDict(
    "InputTypeDef",
    {
        "S3InputDefinition": "S3LocationTypeDef",
        "DataCatalogInputDefinition": "DataCatalogInputDefinitionTypeDef",
    },
    total=False,
)

JobRunTypeDef = TypedDict(
    "JobRunTypeDef",
    {
        "Attempt": int,
        "CompletedOn": datetime,
        "DatasetName": str,
        "ErrorMessage": str,
        "ExecutionTime": int,
        "JobName": str,
        "RunId": str,
        "State": Literal[
            "STARTING", "RUNNING", "STOPPING", "STOPPED", "SUCCEEDED", "FAILED", "TIMEOUT"
        ],
        "LogSubscription": Literal["ENABLE", "DISABLE"],
        "LogGroupName": str,
        "Outputs": List["OutputTypeDef"],
        "RecipeReference": "RecipeReferenceTypeDef",
        "StartedBy": str,
        "StartedOn": datetime,
        "JobSample": "JobSampleTypeDef",
    },
    total=False,
)

JobSampleTypeDef = TypedDict(
    "JobSampleTypeDef", {"Mode": Literal["FULL_DATASET", "CUSTOM_ROWS"], "Size": int}, total=False
)

_RequiredJobTypeDef = TypedDict("_RequiredJobTypeDef", {"Name": str})
_OptionalJobTypeDef = TypedDict(
    "_OptionalJobTypeDef",
    {
        "AccountId": str,
        "CreatedBy": str,
        "CreateDate": datetime,
        "DatasetName": str,
        "EncryptionKeyArn": str,
        "EncryptionMode": Literal["SSE-KMS", "SSE-S3"],
        "Type": Literal["PROFILE", "RECIPE"],
        "LastModifiedBy": str,
        "LastModifiedDate": datetime,
        "LogSubscription": Literal["ENABLE", "DISABLE"],
        "MaxCapacity": int,
        "MaxRetries": int,
        "Outputs": List["OutputTypeDef"],
        "ProjectName": str,
        "RecipeReference": "RecipeReferenceTypeDef",
        "ResourceArn": str,
        "RoleArn": str,
        "Timeout": int,
        "Tags": Dict[str, str],
        "JobSample": "JobSampleTypeDef",
    },
    total=False,
)


class JobTypeDef(_RequiredJobTypeDef, _OptionalJobTypeDef):
    pass


JsonOptionsTypeDef = TypedDict("JsonOptionsTypeDef", {"MultiLine": bool}, total=False)

OutputFormatOptionsTypeDef = TypedDict(
    "OutputFormatOptionsTypeDef", {"Csv": "CsvOutputOptionsTypeDef"}, total=False
)

_RequiredOutputTypeDef = TypedDict("_RequiredOutputTypeDef", {"Location": "S3LocationTypeDef"})
_OptionalOutputTypeDef = TypedDict(
    "_OptionalOutputTypeDef",
    {
        "CompressionFormat": Literal[
            "GZIP", "LZ4", "SNAPPY", "BZIP2", "DEFLATE", "LZO", "BROTLI", "ZSTD", "ZLIB"
        ],
        "Format": Literal["CSV", "JSON", "PARQUET", "GLUEPARQUET", "AVRO", "ORC", "XML"],
        "PartitionColumns": List[str],
        "Overwrite": bool,
        "FormatOptions": "OutputFormatOptionsTypeDef",
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)


class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
    pass


_RequiredProjectTypeDef = TypedDict("_RequiredProjectTypeDef", {"Name": str, "RecipeName": str})
_OptionalProjectTypeDef = TypedDict(
    "_OptionalProjectTypeDef",
    {
        "AccountId": str,
        "CreateDate": datetime,
        "CreatedBy": str,
        "DatasetName": str,
        "LastModifiedDate": datetime,
        "LastModifiedBy": str,
        "ResourceArn": str,
        "Sample": "SampleTypeDef",
        "Tags": Dict[str, str],
        "RoleArn": str,
        "OpenedBy": str,
        "OpenDate": datetime,
    },
    total=False,
)


class ProjectTypeDef(_RequiredProjectTypeDef, _OptionalProjectTypeDef):
    pass


_RequiredRecipeActionTypeDef = TypedDict("_RequiredRecipeActionTypeDef", {"Operation": str})
_OptionalRecipeActionTypeDef = TypedDict(
    "_OptionalRecipeActionTypeDef", {"Parameters": Dict[str, str]}, total=False
)


class RecipeActionTypeDef(_RequiredRecipeActionTypeDef, _OptionalRecipeActionTypeDef):
    pass


_RequiredRecipeReferenceTypeDef = TypedDict("_RequiredRecipeReferenceTypeDef", {"Name": str})
_OptionalRecipeReferenceTypeDef = TypedDict(
    "_OptionalRecipeReferenceTypeDef", {"RecipeVersion": str}, total=False
)


class RecipeReferenceTypeDef(_RequiredRecipeReferenceTypeDef, _OptionalRecipeReferenceTypeDef):
    pass


_RequiredRecipeStepTypeDef = TypedDict(
    "_RequiredRecipeStepTypeDef", {"Action": "RecipeActionTypeDef"}
)
_OptionalRecipeStepTypeDef = TypedDict(
    "_OptionalRecipeStepTypeDef",
    {"ConditionExpressions": List["ConditionExpressionTypeDef"]},
    total=False,
)


class RecipeStepTypeDef(_RequiredRecipeStepTypeDef, _OptionalRecipeStepTypeDef):
    pass


_RequiredRecipeTypeDef = TypedDict("_RequiredRecipeTypeDef", {"Name": str})
_OptionalRecipeTypeDef = TypedDict(
    "_OptionalRecipeTypeDef",
    {
        "CreatedBy": str,
        "CreateDate": datetime,
        "LastModifiedBy": str,
        "LastModifiedDate": datetime,
        "ProjectName": str,
        "PublishedBy": str,
        "PublishedDate": datetime,
        "Description": str,
        "ResourceArn": str,
        "Steps": List["RecipeStepTypeDef"],
        "Tags": Dict[str, str],
        "RecipeVersion": str,
    },
    total=False,
)


class RecipeTypeDef(_RequiredRecipeTypeDef, _OptionalRecipeTypeDef):
    pass


RecipeVersionErrorDetailTypeDef = TypedDict(
    "RecipeVersionErrorDetailTypeDef",
    {"ErrorCode": str, "ErrorMessage": str, "RecipeVersion": str},
    total=False,
)

ResponseMetadata = TypedDict(
    "ResponseMetadata",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, Any],
        "RetryAttempts": int,
    },
)

_RequiredS3LocationTypeDef = TypedDict("_RequiredS3LocationTypeDef", {"Bucket": str})
_OptionalS3LocationTypeDef = TypedDict("_OptionalS3LocationTypeDef", {"Key": str}, total=False)


class S3LocationTypeDef(_RequiredS3LocationTypeDef, _OptionalS3LocationTypeDef):
    pass


_RequiredSampleTypeDef = TypedDict(
    "_RequiredSampleTypeDef", {"Type": Literal["FIRST_N", "LAST_N", "RANDOM"]}
)
_OptionalSampleTypeDef = TypedDict("_OptionalSampleTypeDef", {"Size": int}, total=False)


class SampleTypeDef(_RequiredSampleTypeDef, _OptionalSampleTypeDef):
    pass


_RequiredScheduleTypeDef = TypedDict("_RequiredScheduleTypeDef", {"Name": str})
_OptionalScheduleTypeDef = TypedDict(
    "_OptionalScheduleTypeDef",
    {
        "AccountId": str,
        "CreatedBy": str,
        "CreateDate": datetime,
        "JobNames": List[str],
        "LastModifiedBy": str,
        "LastModifiedDate": datetime,
        "ResourceArn": str,
        "CronExpression": str,
        "Tags": Dict[str, str],
    },
    total=False,
)


class ScheduleTypeDef(_RequiredScheduleTypeDef, _OptionalScheduleTypeDef):
    pass


_RequiredBatchDeleteRecipeVersionResponseTypeDef = TypedDict(
    "_RequiredBatchDeleteRecipeVersionResponseTypeDef", {"Name": str}
)
_OptionalBatchDeleteRecipeVersionResponseTypeDef = TypedDict(
    "_OptionalBatchDeleteRecipeVersionResponseTypeDef",
    {"Errors": List["RecipeVersionErrorDetailTypeDef"]},
    total=False,
)


class BatchDeleteRecipeVersionResponseTypeDef(
    _RequiredBatchDeleteRecipeVersionResponseTypeDef,
    _OptionalBatchDeleteRecipeVersionResponseTypeDef,
):
    pass


CreateDatasetResponseTypeDef = TypedDict("CreateDatasetResponseTypeDef", {"Name": str})

CreateProfileJobResponseTypeDef = TypedDict("CreateProfileJobResponseTypeDef", {"Name": str})

CreateProjectResponseTypeDef = TypedDict("CreateProjectResponseTypeDef", {"Name": str})

CreateRecipeJobResponseTypeDef = TypedDict("CreateRecipeJobResponseTypeDef", {"Name": str})

CreateRecipeResponseTypeDef = TypedDict("CreateRecipeResponseTypeDef", {"Name": str})

CreateScheduleResponseTypeDef = TypedDict("CreateScheduleResponseTypeDef", {"Name": str})

DeleteDatasetResponseTypeDef = TypedDict("DeleteDatasetResponseTypeDef", {"Name": str})

DeleteJobResponseTypeDef = TypedDict("DeleteJobResponseTypeDef", {"Name": str})

DeleteProjectResponseTypeDef = TypedDict("DeleteProjectResponseTypeDef", {"Name": str})

DeleteRecipeVersionResponseTypeDef = TypedDict(
    "DeleteRecipeVersionResponseTypeDef", {"Name": str, "RecipeVersion": str}
)

DeleteScheduleResponseTypeDef = TypedDict("DeleteScheduleResponseTypeDef", {"Name": str})

_RequiredDescribeDatasetResponseTypeDef = TypedDict(
    "_RequiredDescribeDatasetResponseTypeDef", {"Name": str, "Input": "InputTypeDef"}
)
_OptionalDescribeDatasetResponseTypeDef = TypedDict(
    "_OptionalDescribeDatasetResponseTypeDef",
    {
        "CreatedBy": str,
        "CreateDate": datetime,
        "Format": Literal["CSV", "JSON", "PARQUET", "EXCEL"],
        "FormatOptions": "FormatOptionsTypeDef",
        "LastModifiedDate": datetime,
        "LastModifiedBy": str,
        "Source": Literal["S3", "DATA-CATALOG"],
        "Tags": Dict[str, str],
        "ResourceArn": str,
    },
    total=False,
)


class DescribeDatasetResponseTypeDef(
    _RequiredDescribeDatasetResponseTypeDef, _OptionalDescribeDatasetResponseTypeDef
):
    pass


_RequiredDescribeJobResponseTypeDef = TypedDict(
    "_RequiredDescribeJobResponseTypeDef", {"Name": str}
)
_OptionalDescribeJobResponseTypeDef = TypedDict(
    "_OptionalDescribeJobResponseTypeDef",
    {
        "CreateDate": datetime,
        "CreatedBy": str,
        "DatasetName": str,
        "EncryptionKeyArn": str,
        "EncryptionMode": Literal["SSE-KMS", "SSE-S3"],
        "Type": Literal["PROFILE", "RECIPE"],
        "LastModifiedBy": str,
        "LastModifiedDate": datetime,
        "LogSubscription": Literal["ENABLE", "DISABLE"],
        "MaxCapacity": int,
        "MaxRetries": int,
        "Outputs": List["OutputTypeDef"],
        "ProjectName": str,
        "RecipeReference": "RecipeReferenceTypeDef",
        "ResourceArn": str,
        "RoleArn": str,
        "Tags": Dict[str, str],
        "Timeout": int,
        "JobSample": "JobSampleTypeDef",
    },
    total=False,
)


class DescribeJobResponseTypeDef(
    _RequiredDescribeJobResponseTypeDef, _OptionalDescribeJobResponseTypeDef
):
    pass


_RequiredDescribeJobRunResponseTypeDef = TypedDict(
    "_RequiredDescribeJobRunResponseTypeDef", {"JobName": str}
)
_OptionalDescribeJobRunResponseTypeDef = TypedDict(
    "_OptionalDescribeJobRunResponseTypeDef",
    {
        "Attempt": int,
        "CompletedOn": datetime,
        "DatasetName": str,
        "ErrorMessage": str,
        "ExecutionTime": int,
        "RunId": str,
        "State": Literal[
            "STARTING", "RUNNING", "STOPPING", "STOPPED", "SUCCEEDED", "FAILED", "TIMEOUT"
        ],
        "LogSubscription": Literal["ENABLE", "DISABLE"],
        "LogGroupName": str,
        "Outputs": List["OutputTypeDef"],
        "RecipeReference": "RecipeReferenceTypeDef",
        "StartedBy": str,
        "StartedOn": datetime,
        "JobSample": "JobSampleTypeDef",
    },
    total=False,
)


class DescribeJobRunResponseTypeDef(
    _RequiredDescribeJobRunResponseTypeDef, _OptionalDescribeJobRunResponseTypeDef
):
    pass


_RequiredDescribeProjectResponseTypeDef = TypedDict(
    "_RequiredDescribeProjectResponseTypeDef", {"Name": str}
)
_OptionalDescribeProjectResponseTypeDef = TypedDict(
    "_OptionalDescribeProjectResponseTypeDef",
    {
        "CreateDate": datetime,
        "CreatedBy": str,
        "DatasetName": str,
        "LastModifiedDate": datetime,
        "LastModifiedBy": str,
        "RecipeName": str,
        "ResourceArn": str,
        "Sample": "SampleTypeDef",
        "RoleArn": str,
        "Tags": Dict[str, str],
        "SessionStatus": Literal[
            "ASSIGNED",
            "FAILED",
            "INITIALIZING",
            "PROVISIONING",
            "READY",
            "RECYCLING",
            "ROTATING",
            "TERMINATED",
            "TERMINATING",
            "UPDATING",
        ],
        "OpenedBy": str,
        "OpenDate": datetime,
    },
    total=False,
)


class DescribeProjectResponseTypeDef(
    _RequiredDescribeProjectResponseTypeDef, _OptionalDescribeProjectResponseTypeDef
):
    pass


_RequiredDescribeRecipeResponseTypeDef = TypedDict(
    "_RequiredDescribeRecipeResponseTypeDef", {"Name": str}
)
_OptionalDescribeRecipeResponseTypeDef = TypedDict(
    "_OptionalDescribeRecipeResponseTypeDef",
    {
        "CreatedBy": str,
        "CreateDate": datetime,
        "LastModifiedBy": str,
        "LastModifiedDate": datetime,
        "ProjectName": str,
        "PublishedBy": str,
        "PublishedDate": datetime,
        "Description": str,
        "Steps": List["RecipeStepTypeDef"],
        "Tags": Dict[str, str],
        "ResourceArn": str,
        "RecipeVersion": str,
    },
    total=False,
)


class DescribeRecipeResponseTypeDef(
    _RequiredDescribeRecipeResponseTypeDef, _OptionalDescribeRecipeResponseTypeDef
):
    pass


_RequiredDescribeScheduleResponseTypeDef = TypedDict(
    "_RequiredDescribeScheduleResponseTypeDef", {"Name": str}
)
_OptionalDescribeScheduleResponseTypeDef = TypedDict(
    "_OptionalDescribeScheduleResponseTypeDef",
    {
        "CreateDate": datetime,
        "CreatedBy": str,
        "JobNames": List[str],
        "LastModifiedBy": str,
        "LastModifiedDate": datetime,
        "ResourceArn": str,
        "CronExpression": str,
        "Tags": Dict[str, str],
    },
    total=False,
)


class DescribeScheduleResponseTypeDef(
    _RequiredDescribeScheduleResponseTypeDef, _OptionalDescribeScheduleResponseTypeDef
):
    pass


_RequiredListDatasetsResponseTypeDef = TypedDict(
    "_RequiredListDatasetsResponseTypeDef", {"Datasets": List["DatasetTypeDef"]}
)
_OptionalListDatasetsResponseTypeDef = TypedDict(
    "_OptionalListDatasetsResponseTypeDef", {"NextToken": str}, total=False
)


class ListDatasetsResponseTypeDef(
    _RequiredListDatasetsResponseTypeDef, _OptionalListDatasetsResponseTypeDef
):
    pass


_RequiredListJobRunsResponseTypeDef = TypedDict(
    "_RequiredListJobRunsResponseTypeDef", {"JobRuns": List["JobRunTypeDef"]}
)
_OptionalListJobRunsResponseTypeDef = TypedDict(
    "_OptionalListJobRunsResponseTypeDef", {"NextToken": str}, total=False
)


class ListJobRunsResponseTypeDef(
    _RequiredListJobRunsResponseTypeDef, _OptionalListJobRunsResponseTypeDef
):
    pass


_RequiredListJobsResponseTypeDef = TypedDict(
    "_RequiredListJobsResponseTypeDef", {"Jobs": List["JobTypeDef"]}
)
_OptionalListJobsResponseTypeDef = TypedDict(
    "_OptionalListJobsResponseTypeDef", {"NextToken": str}, total=False
)


class ListJobsResponseTypeDef(_RequiredListJobsResponseTypeDef, _OptionalListJobsResponseTypeDef):
    pass


_RequiredListProjectsResponseTypeDef = TypedDict(
    "_RequiredListProjectsResponseTypeDef", {"Projects": List["ProjectTypeDef"]}
)
_OptionalListProjectsResponseTypeDef = TypedDict(
    "_OptionalListProjectsResponseTypeDef", {"NextToken": str}, total=False
)


class ListProjectsResponseTypeDef(
    _RequiredListProjectsResponseTypeDef, _OptionalListProjectsResponseTypeDef
):
    pass


_RequiredListRecipeVersionsResponseTypeDef = TypedDict(
    "_RequiredListRecipeVersionsResponseTypeDef", {"Recipes": List["RecipeTypeDef"]}
)
_OptionalListRecipeVersionsResponseTypeDef = TypedDict(
    "_OptionalListRecipeVersionsResponseTypeDef", {"NextToken": str}, total=False
)


class ListRecipeVersionsResponseTypeDef(
    _RequiredListRecipeVersionsResponseTypeDef, _OptionalListRecipeVersionsResponseTypeDef
):
    pass


_RequiredListRecipesResponseTypeDef = TypedDict(
    "_RequiredListRecipesResponseTypeDef", {"Recipes": List["RecipeTypeDef"]}
)
_OptionalListRecipesResponseTypeDef = TypedDict(
    "_OptionalListRecipesResponseTypeDef", {"NextToken": str}, total=False
)


class ListRecipesResponseTypeDef(
    _RequiredListRecipesResponseTypeDef, _OptionalListRecipesResponseTypeDef
):
    pass


_RequiredListSchedulesResponseTypeDef = TypedDict(
    "_RequiredListSchedulesResponseTypeDef", {"Schedules": List["ScheduleTypeDef"]}
)
_OptionalListSchedulesResponseTypeDef = TypedDict(
    "_OptionalListSchedulesResponseTypeDef", {"NextToken": str}, total=False
)


class ListSchedulesResponseTypeDef(
    _RequiredListSchedulesResponseTypeDef, _OptionalListSchedulesResponseTypeDef
):
    pass


ListTagsForResourceResponseTypeDef = TypedDict(
    "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
)

PublishRecipeResponseTypeDef = TypedDict("PublishRecipeResponseTypeDef", {"Name": str})

_RequiredSendProjectSessionActionResponseTypeDef = TypedDict(
    "_RequiredSendProjectSessionActionResponseTypeDef", {"Name": str}
)
_OptionalSendProjectSessionActionResponseTypeDef = TypedDict(
    "_OptionalSendProjectSessionActionResponseTypeDef",
    {"Result": str, "ActionId": int},
    total=False,
)


class SendProjectSessionActionResponseTypeDef(
    _RequiredSendProjectSessionActionResponseTypeDef,
    _OptionalSendProjectSessionActionResponseTypeDef,
):
    pass


StartJobRunResponseTypeDef = TypedDict("StartJobRunResponseTypeDef", {"RunId": str})

_RequiredStartProjectSessionResponseTypeDef = TypedDict(
    "_RequiredStartProjectSessionResponseTypeDef", {"Name": str}
)
_OptionalStartProjectSessionResponseTypeDef = TypedDict(
    "_OptionalStartProjectSessionResponseTypeDef", {"ClientSessionId": str}, total=False
)


class StartProjectSessionResponseTypeDef(
    _RequiredStartProjectSessionResponseTypeDef, _OptionalStartProjectSessionResponseTypeDef
):
    pass


StopJobRunResponseTypeDef = TypedDict("StopJobRunResponseTypeDef", {"RunId": str})

UpdateDatasetResponseTypeDef = TypedDict("UpdateDatasetResponseTypeDef", {"Name": str})

UpdateProfileJobResponseTypeDef = TypedDict("UpdateProfileJobResponseTypeDef", {"Name": str})

_RequiredUpdateProjectResponseTypeDef = TypedDict(
    "_RequiredUpdateProjectResponseTypeDef", {"Name": str}
)
_OptionalUpdateProjectResponseTypeDef = TypedDict(
    "_OptionalUpdateProjectResponseTypeDef", {"LastModifiedDate": datetime}, total=False
)


class UpdateProjectResponseTypeDef(
    _RequiredUpdateProjectResponseTypeDef, _OptionalUpdateProjectResponseTypeDef
):
    pass


UpdateRecipeJobResponseTypeDef = TypedDict("UpdateRecipeJobResponseTypeDef", {"Name": str})

UpdateRecipeResponseTypeDef = TypedDict("UpdateRecipeResponseTypeDef", {"Name": str})

UpdateScheduleResponseTypeDef = TypedDict("UpdateScheduleResponseTypeDef", {"Name": str})

_RequiredViewFrameTypeDef = TypedDict("_RequiredViewFrameTypeDef", {"StartColumnIndex": int})
_OptionalViewFrameTypeDef = TypedDict(
    "_OptionalViewFrameTypeDef", {"ColumnRange": int, "HiddenColumns": List[str]}, total=False
)


class ViewFrameTypeDef(_RequiredViewFrameTypeDef, _OptionalViewFrameTypeDef):
    pass



"""
Main interface for databrew service client

Usage::

    ```python
    import boto3
    from mypy_boto3_databrew import GlueDataBrewClient

    client: GlueDataBrewClient = boto3.client("databrew")
    ```
"""
import sys
from typing import Any, Dict, List, Type, overload

from botocore.client import ClientMeta

from mypy_boto3_databrew.paginator import (
    ListDatasetsPaginator,
    ListJobRunsPaginator,
    ListJobsPaginator,
    ListProjectsPaginator,
    ListRecipesPaginator,
    ListRecipeVersionsPaginator,
    ListSchedulesPaginator,
)
from mypy_boto3_databrew.type_defs import (
    BatchDeleteRecipeVersionResponseTypeDef,
    CreateDatasetResponseTypeDef,
    CreateProfileJobResponseTypeDef,
    CreateProjectResponseTypeDef,
    CreateRecipeJobResponseTypeDef,
    CreateRecipeResponseTypeDef,
    CreateScheduleResponseTypeDef,
    DeleteDatasetResponseTypeDef,
    DeleteJobResponseTypeDef,
    DeleteProjectResponseTypeDef,
    DeleteRecipeVersionResponseTypeDef,
    DeleteScheduleResponseTypeDef,
    DescribeDatasetResponseTypeDef,
    DescribeJobResponseTypeDef,
    DescribeJobRunResponseTypeDef,
    DescribeProjectResponseTypeDef,
    DescribeRecipeResponseTypeDef,
    DescribeScheduleResponseTypeDef,
    FormatOptionsTypeDef,
    InputTypeDef,
    JobSampleTypeDef,
    ListDatasetsResponseTypeDef,
    ListJobRunsResponseTypeDef,
    ListJobsResponseTypeDef,
    ListProjectsResponseTypeDef,
    ListRecipesResponseTypeDef,
    ListRecipeVersionsResponseTypeDef,
    ListSchedulesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    OutputTypeDef,
    PublishRecipeResponseTypeDef,
    RecipeReferenceTypeDef,
    RecipeStepTypeDef,
    S3LocationTypeDef,
    SampleTypeDef,
    SendProjectSessionActionResponseTypeDef,
    StartJobRunResponseTypeDef,
    StartProjectSessionResponseTypeDef,
    StopJobRunResponseTypeDef,
    UpdateDatasetResponseTypeDef,
    UpdateProfileJobResponseTypeDef,
    UpdateProjectResponseTypeDef,
    UpdateRecipeJobResponseTypeDef,
    UpdateRecipeResponseTypeDef,
    UpdateScheduleResponseTypeDef,
    ViewFrameTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = ("GlueDataBrewClient",)

class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str
    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str

class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class GlueDataBrewClient:
    """
    [GlueDataBrew.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client)
    """

    meta: ClientMeta
    exceptions: Exceptions
    def batch_delete_recipe_version(
        self, Name: str, RecipeVersions: List[str]
    ) -> BatchDeleteRecipeVersionResponseTypeDef:
        """
        [Client.batch_delete_recipe_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
        """
    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
        """
    def create_dataset(
        self,
        Name: str,
        Input: "InputTypeDef",
        Format: Literal["CSV", "JSON", "PARQUET", "EXCEL"] = None,
        FormatOptions: "FormatOptionsTypeDef" = None,
        Tags: Dict[str, str] = None,
    ) -> CreateDatasetResponseTypeDef:
        """
        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
        """
    def create_profile_job(
        self,
        DatasetName: str,
        Name: str,
        OutputLocation: "S3LocationTypeDef",
        RoleArn: str,
        EncryptionKeyArn: str = None,
        EncryptionMode: Literal["SSE-KMS", "SSE-S3"] = None,
        LogSubscription: Literal["ENABLE", "DISABLE"] = None,
        MaxCapacity: int = None,
        MaxRetries: int = None,
        Tags: Dict[str, str] = None,
        Timeout: int = None,
        JobSample: "JobSampleTypeDef" = None,
    ) -> CreateProfileJobResponseTypeDef:
        """
        [Client.create_profile_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
        """
    def create_project(
        self,
        DatasetName: str,
        Name: str,
        RecipeName: str,
        RoleArn: str,
        Sample: "SampleTypeDef" = None,
        Tags: Dict[str, str] = None,
    ) -> CreateProjectResponseTypeDef:
        """
        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.create_project)
        """
    def create_recipe(
        self,
        Name: str,
        Steps: List["RecipeStepTypeDef"],
        Description: str = None,
        Tags: Dict[str, str] = None,
    ) -> CreateRecipeResponseTypeDef:
        """
        [Client.create_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
        """
    def create_recipe_job(
        self,
        Name: str,
        Outputs: List["OutputTypeDef"],
        RoleArn: str,
        DatasetName: str = None,
        EncryptionKeyArn: str = None,
        EncryptionMode: Literal["SSE-KMS", "SSE-S3"] = None,
        LogSubscription: Literal["ENABLE", "DISABLE"] = None,
        MaxCapacity: int = None,
        MaxRetries: int = None,
        ProjectName: str = None,
        RecipeReference: "RecipeReferenceTypeDef" = None,
        Tags: Dict[str, str] = None,
        Timeout: int = None,
    ) -> CreateRecipeJobResponseTypeDef:
        """
        [Client.create_recipe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
        """
    def create_schedule(
        self,
        CronExpression: str,
        Name: str,
        JobNames: List[str] = None,
        Tags: Dict[str, str] = None,
    ) -> CreateScheduleResponseTypeDef:
        """
        [Client.create_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
        """
    def delete_dataset(self, Name: str) -> DeleteDatasetResponseTypeDef:
        """
        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
        """
    def delete_job(self, Name: str) -> DeleteJobResponseTypeDef:
        """
        [Client.delete_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
        """
    def delete_project(self, Name: str) -> DeleteProjectResponseTypeDef:
        """
        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
        """
    def delete_recipe_version(
        self, Name: str, RecipeVersion: str
    ) -> DeleteRecipeVersionResponseTypeDef:
        """
        [Client.delete_recipe_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
        """
    def delete_schedule(self, Name: str) -> DeleteScheduleResponseTypeDef:
        """
        [Client.delete_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
        """
    def describe_dataset(self, Name: str) -> DescribeDatasetResponseTypeDef:
        """
        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
        """
    def describe_job(self, Name: str) -> DescribeJobResponseTypeDef:
        """
        [Client.describe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
        """
    def describe_job_run(self, Name: str, RunId: str) -> DescribeJobRunResponseTypeDef:
        """
        [Client.describe_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
        """
    def describe_project(self, Name: str) -> DescribeProjectResponseTypeDef:
        """
        [Client.describe_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
        """
    def describe_recipe(
        self, Name: str, RecipeVersion: str = None
    ) -> DescribeRecipeResponseTypeDef:
        """
        [Client.describe_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
        """
    def describe_schedule(self, Name: str) -> DescribeScheduleResponseTypeDef:
        """
        [Client.describe_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
        """
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
        """
    def list_datasets(
        self, MaxResults: int = None, NextToken: str = None
    ) -> ListDatasetsResponseTypeDef:
        """
        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
        """
    def list_job_runs(
        self, Name: str, MaxResults: int = None, NextToken: str = None
    ) -> ListJobRunsResponseTypeDef:
        """
        [Client.list_job_runs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
        """
    def list_jobs(
        self,
        DatasetName: str = None,
        MaxResults: int = None,
        NextToken: str = None,
        ProjectName: str = None,
    ) -> ListJobsResponseTypeDef:
        """
        [Client.list_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
        """
    def list_projects(
        self, NextToken: str = None, MaxResults: int = None
    ) -> ListProjectsResponseTypeDef:
        """
        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
        """
    def list_recipe_versions(
        self, Name: str, MaxResults: int = None, NextToken: str = None
    ) -> ListRecipeVersionsResponseTypeDef:
        """
        [Client.list_recipe_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
        """
    def list_recipes(
        self, MaxResults: int = None, NextToken: str = None, RecipeVersion: str = None
    ) -> ListRecipesResponseTypeDef:
        """
        [Client.list_recipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
        """
    def list_schedules(
        self, JobName: str = None, MaxResults: int = None, NextToken: str = None
    ) -> ListSchedulesResponseTypeDef:
        """
        [Client.list_schedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
        """
    def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
        """
    def publish_recipe(self, Name: str, Description: str = None) -> PublishRecipeResponseTypeDef:
        """
        [Client.publish_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
        """
    def send_project_session_action(
        self,
        Name: str,
        Preview: bool = None,
        RecipeStep: "RecipeStepTypeDef" = None,
        StepIndex: int = None,
        ClientSessionId: str = None,
        ViewFrame: ViewFrameTypeDef = None,
    ) -> SendProjectSessionActionResponseTypeDef:
        """
        [Client.send_project_session_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
        """
    def start_job_run(self, Name: str) -> StartJobRunResponseTypeDef:
        """
        [Client.start_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
        """
    def start_project_session(
        self, Name: str, AssumeControl: bool = None
    ) -> StartProjectSessionResponseTypeDef:
        """
        [Client.start_project_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
        """
    def stop_job_run(self, Name: str, RunId: str) -> StopJobRunResponseTypeDef:
        """
        [Client.stop_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
        """
    def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
        """
    def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
        """
    def update_dataset(
        self,
        Name: str,
        Input: "InputTypeDef",
        Format: Literal["CSV", "JSON", "PARQUET", "EXCEL"] = None,
        FormatOptions: "FormatOptionsTypeDef" = None,
    ) -> UpdateDatasetResponseTypeDef:
        """
        [Client.update_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
        """
    def update_profile_job(
        self,
        Name: str,
        OutputLocation: "S3LocationTypeDef",
        RoleArn: str,
        EncryptionKeyArn: str = None,
        EncryptionMode: Literal["SSE-KMS", "SSE-S3"] = None,
        LogSubscription: Literal["ENABLE", "DISABLE"] = None,
        MaxCapacity: int = None,
        MaxRetries: int = None,
        Timeout: int = None,
        JobSample: "JobSampleTypeDef" = None,
    ) -> UpdateProfileJobResponseTypeDef:
        """
        [Client.update_profile_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
        """
    def update_project(
        self, RoleArn: str, Name: str, Sample: "SampleTypeDef" = None
    ) -> UpdateProjectResponseTypeDef:
        """
        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.update_project)
        """
    def update_recipe(
        self, Name: str, Description: str = None, Steps: List["RecipeStepTypeDef"] = None
    ) -> UpdateRecipeResponseTypeDef:
        """
        [Client.update_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
        """
    def update_recipe_job(
        self,
        Name: str,
        Outputs: List["OutputTypeDef"],
        RoleArn: str,
        EncryptionKeyArn: str = None,
        EncryptionMode: Literal["SSE-KMS", "SSE-S3"] = None,
        LogSubscription: Literal["ENABLE", "DISABLE"] = None,
        MaxCapacity: int = None,
        MaxRetries: int = None,
        Timeout: int = None,
    ) -> UpdateRecipeJobResponseTypeDef:
        """
        [Client.update_recipe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
        """
    def update_schedule(
        self, CronExpression: str, Name: str, JobNames: List[str] = None
    ) -> UpdateScheduleResponseTypeDef:
        """
        [Client.update_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
        """
        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
        """
        [Paginator.ListJobRuns documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
        """
        [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
        """
        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_recipe_versions"]
    ) -> ListRecipeVersionsPaginator:
        """
        [Paginator.ListRecipeVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_recipes"]) -> ListRecipesPaginator:
        """
        [Paginator.ListRecipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_schedules"]) -> ListSchedulesPaginator:
        """
        [Paginator.ListSchedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.30/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
        """
